# See LICENSE.incore for details

"""Top-level package for RISC-V ISA Coverage."""

__author__ = """InCore Semiconductors Pvt Ltd"""
__email__ = 'info@incoresemi.com'
__version__ = '0.3.1'
